Module error

Module error 

A bunch of wrap errors.

Enums

Error
Errors enum mapping global custom errors. The error type can be expressed in decimal, where the high decs represent the error category and the low decs represent the error type.

Type Aliases

Result
A wrap Result contains custom errors.