pub struct PeriodicMeasure { /* private fields */ }Expand description
PeriodicMeasure is used to assess the reliability of peers by counting their behaviour.
It currently count the number of sent and received messages in a given period (1 hour).
The method Measure::incr should be called in the proper places.
Implementations
Sourceimpl PeriodicMeasure
impl PeriodicMeasure
Sourcepub fn new(storage: MeasureStorage) -> Self
pub fn new(storage: MeasureStorage) -> Self
Create a new PeriodicMeasure with the given storage.