Module cli

Module cli 

ring-node-client

ring-node-client is a command-line tool for interacting with the Ring Node backend API. It allows users to establish WebRTC connections with remote peers, send and receive messages, and publish and subscribe to topics.

Usage

To use ring-node-client, simply create a new instance of the Client struct, passing in the endpoint URL and signature as arguments. Then, use the various methods on the Client instance to perform the desired actions.

Features

  • Establish WebRTC connections with remote peers using HTTP as a signaling channel.
  • Send and receive messages using WebRTC.
  • Publish and subscribe to topics.
  • Register and lookup DIDs of services.
  • Send HTTP requests to remote peers.
  • Load a seed file to establish a connection with a remote peer.

Structs

Client
Wrap json_client send request between nodes or browsers.
ClientOutput
Wrap client output contain raw result and humanreadable display.