Module endpoint

Module endpoint 

Native JSON-RPC endpoint server. rings-node service run with Swarm and chord stabilization.

Structs

GatewayStatusState
Gateway status endpoint state.
JsonResponse
JSON response struct
JsonRpcState
JSON-RPC state
StatusState
Status state
WsState
websocket state

Functions

run_external_api
Run a web server to handle jsonrpc request from external
run_internal_api
Run a web server to handle jsonrpc request locally
run_internal_api_with_gateway
Run the local JSON-RPC server with an optional foreground-gateway status endpoint.