pub struct NativeGatewayRunner { /* private fields */ }Expand description
Prepared foreground gateway with a status capability available before platform setup.
Implementations
Sourceimpl NativeGatewayRunner
impl NativeGatewayRunner
Sourcepub fn new(
processor: Arc<Processor>,
onion: NativeOnionCircuitHandle,
config: NativeGatewayConfig,
) -> Result<Self>
pub fn new( processor: Arc<Processor>, onion: NativeOnionCircuitHandle, config: NativeGatewayConfig, ) -> Result<Self>
Build the pure runtime and Onion connector without changing host network state.
Sourcepub fn status_handle(&self) -> GatewayStatusHandle
pub fn status_handle(&self) -> GatewayStatusHandle
Return process-independent status for the native HTTP inspection endpoint.