encode_initial_forward

Function encode_initial_forward 

pub fn encode_initial_forward(
    client: OnionClientReturn,
    route: &OnionRoute,
    circuit_id: OnionCircuitId,
    payload: OnionCircuitPayload,
) -> Result<(Did, Bytes)>
Encode the first forward frame for route.

Pre: payload.service names the same service that selected route. Post: the encrypted exit layer cannot carry a payload for a service different from the selected exit descriptor service.