pub struct OnionBackwardFrame {
pub circuit_id: OnionCircuitId,
pub payload: AeadCiphertext,
}Expand description
Backward direction: exit -> relays -> client.
Fields
circuit_id: OnionCircuitIdEdge-local circuit id for the receiving relay or client.
payload: AeadCiphertextAEAD payload encrypted to the client session public key.