pub struct OnionBackwardPath {
pub circuit_id: OnionCircuitId,
pub return_peer: Did,
pub return_session_public_key: PublicKey<33>,
pub client: OnionClientReturn,
}Expand description
Authenticated immediate path used to originate one backward cell at an exit.
Fields
circuit_id: OnionCircuitIdEdge-local circuit id expected by the immediate return peer.
return_peer: DidImmediate overlay return peer.
return_session_public_key: PublicKey<33>Session key that encrypts the hop-to-hop return cell.
client: OnionClientReturnClient-only key and return id for the inner signed payload.
Implementations
Sourceimpl OnionBackwardPath
impl OnionBackwardPath
Sourcepub const fn new(
circuit_id: OnionCircuitId,
return_peer: Did,
return_session_public_key: PublicKey<33>,
client: OnionClientReturn,
) -> Self
pub const fn new( circuit_id: OnionCircuitId, return_peer: Did, return_session_public_key: PublicKey<33>, client: OnionClientReturn, ) -> Self
Build a return path from values authenticated in the decrypted exit layer.