pub struct OnionProxyConfig {
pub protocol: OnionProxyProtocol,
pub hop_count: usize,
pub allow_short_paths: bool,
/* private fields */
}Expand description
Target-agnostic onion proxy configuration.
A client owns one proxy configuration per ingress style, then resolves one route per target authority. This keeps browser proxy APIs from becoming one-off URL fetch wrappers.
Fields
protocol: OnionProxyProtocolRequested ingress protocol.
hop_count: usizeDesired hop count including the exit. 0 uses crate::onion::DEFAULT_ONION_ROUTE_HOPS.
allow_short_paths: boolWhether route selection may use fewer hops when too few relays are live.
Implementations
Sourceimpl OnionProxyConfig
impl OnionProxyConfig
Sourcepub fn new(
protocol: OnionProxyProtocol,
hop_count: usize,
allow_short_paths: bool,
) -> Self
pub fn new( protocol: OnionProxyProtocol, hop_count: usize, allow_short_paths: bool, ) -> Self
Create a proxy configuration for protocol.
Sourcepub fn with_service(
protocol: OnionProxyProtocol,
service: OnionServiceName,
hop_count: usize,
allow_short_paths: bool,
) -> Result<Self>
pub fn with_service( protocol: OnionProxyProtocol, service: OnionServiceName, hop_count: usize, allow_short_paths: bool, ) -> Result<Self>
Create a proxy configuration with an explicit exit service.
Sourcepub fn tcp_connect(hop_count: usize, allow_short_paths: bool) -> Self
pub fn tcp_connect(hop_count: usize, allow_short_paths: bool) -> Self
Create a native TCP CONNECT proxy configuration.
Sourcepub fn tcp_connect_service(
service: OnionServiceName,
hop_count: usize,
allow_short_paths: bool,
) -> Result<Self>
pub fn tcp_connect_service( service: OnionServiceName, hop_count: usize, allow_short_paths: bool, ) -> Result<Self>
Create a native TCP CONNECT proxy configuration for a specific TCP exit service.
Sourcepub fn https_proxy(hop_count: usize, allow_short_paths: bool) -> Self
pub fn https_proxy(hop_count: usize, allow_short_paths: bool) -> Self
Create an HTTPS proxy configuration.
Sourcepub fn exit_service(&self) -> &str
pub fn exit_service(&self) -> &str
Return the onion-exit service name required by this proxy.
Sourcepub fn exit_service_name(&self) -> &OnionServiceName
pub fn exit_service_name(&self) -> &OnionServiceName
Return the canonical onion-exit service required by this proxy.
Sourcepub fn exit_transport(&self) -> OnionExitTransport
pub fn exit_transport(&self) -> OnionExitTransport
Return the onion-exit transport required by this proxy.