Module route

Module route 

Onion route selection.

Structs

OnionRoute
Selected onion route.
OnionRouteHop
One hop selected for encrypted onion routing.
OnionRouteRequest
Route-building request for an onion circuit.

Constants

DEFAULT_ONION_ROUTE_HOPS
Default number of DID hops in a production onion route, including the exit.

Functions

select_onion_route
Select an onion route from live presence and exit descriptors.