pub struct OnionRouteRequest {
pub service: OnionServiceName,
pub hop_count: usize,
pub allow_short_paths: bool,
}Expand description
Route-building request for an onion circuit.
Fields
service: OnionServiceNameExit service required by the route.
hop_count: usizeDesired hop count including the exit. 0 uses DEFAULT_ONION_ROUTE_HOPS.
allow_short_paths: boolWhether a route may be shorter than hop_count when the network is too small.
Implementations
Sourceimpl OnionRouteRequest
impl OnionRouteRequest
Sourcepub fn new(
service: impl AsRef<str>,
hop_count: usize,
allow_short_paths: bool,
) -> Result<Self>
pub fn new( service: impl AsRef<str>, hop_count: usize, allow_short_paths: bool, ) -> Result<Self>
Build a route request from an untrusted service string.
Sourcepub fn from_service_name(
service: OnionServiceName,
hop_count: usize,
allow_short_paths: bool,
) -> Self
pub fn from_service_name( service: OnionServiceName, hop_count: usize, allow_short_paths: bool, ) -> Self
Build a route request from an already canonical service name.