Module tcp

Module tcp 

Native TCP adapter for route-aware onion circuits.

Structs

NativeOnionCircuitHandle
Native handle for opening TCP streams over route-aware onion circuits.
NativeOnionOpenStream
Client-side onion TCP stream after the exit has accepted and connected the target.
NativeOnionTcpExitConfig
Native TCP exit capabilities installed into the onion circuit data plane.