pub struct EntryLookupEvidence {
pub entry: Entry,
pub misses: Vec<PlacementMiss>,
}Expand description
A successful lookup result plus the missing placements observed before it.
Fields
entry: EntryEntry found by the lookup.
misses: Vec<PlacementMiss>Placement misses observed as part of the same lookup.
Implementations
Sourceimpl EntryLookupEvidence
impl EntryLookupEvidence
Sourcepub fn new(entry: Entry, misses: Vec<PlacementMiss>) -> EntryLookupEvidence
pub fn new(entry: Entry, misses: Vec<PlacementMiss>) -> EntryLookupEvidence
Construct lookup evidence.