PlacedEntry

Struct PlacedEntry 

pub struct PlacedEntry {
    pub key: Did,
    pub entry: Entry,
}
An Entry paired with its Chord placement key.

key is the DHT storage location. entry.did is the resource identity. These two values may differ for redundant replicas.

Fields

key: Did

The key used to place this value in DHT storage.

entry: Entry

The stored entry value.

Implementations

Source

impl PlacedEntry

pub fn new(key: Did, entry: Entry) -> PlacedEntry

Pair an entry value with the key where it is stored.

pub fn placement_belongs_to_entry(&self, redundancy: u16) -> Result<bool, Error>

Return whether key is in entry.did’s affine replica set.

pub fn validate_placement(&self, redundancy: u16) -> Result<(), Error>

Enforce that key belongs to entry.did’s affine replica set.