pub struct PlacementMiss {
pub key: Did,
pub owner: Did,
}Expand description
A placement key observed missing during lookup.
Fields
key: DidPlacement key whose responsible owner returned None.
owner: DidOwner that was responsible for key when the miss was observed.
Implementations
Sourceimpl PlacementMiss
impl PlacementMiss
Sourcepub fn new(key: Did, owner: Did) -> PlacementMiss
pub fn new(key: Did, owner: Did) -> PlacementMiss
Witness that owner was queried for key and did not have the entry.