pub struct E2eStreamDecryptor { /* private fields */ }Expand description
Stateful streaming decryptor for direct ElGamal body frames.
Implementations
Sourceimpl E2eStreamDecryptor
impl E2eStreamDecryptor
Sourcepub fn new(
stream_id: Uuid,
expected_sender: Did,
recipient_secret_key: SecretKey,
) -> E2eStreamDecryptor
pub fn new( stream_id: Uuid, expected_sender: Did, recipient_secret_key: SecretKey, ) -> E2eStreamDecryptor
Create a direct ElGamal streaming decryptor for a recipient secret key.
Sourcepub fn with_reorder_window(
stream_id: Uuid,
expected_sender: Did,
recipient_secret_key: SecretKey,
reorder_window: u64,
) -> E2eStreamDecryptor
pub fn with_reorder_window( stream_id: Uuid, expected_sender: Did, recipient_secret_key: SecretKey, reorder_window: u64, ) -> E2eStreamDecryptor
Create a decryptor with an explicit future-frame reorder window.
Sourcepub fn decrypt_next(&mut self, frame: &E2eStreamFrame) -> Result<Vec<u8>, Error>
pub fn decrypt_next(&mut self, frame: &E2eStreamFrame) -> Result<Vec<u8>, Error>
Decrypt one frame and return newly contiguous plaintext bytes.
Out-of-order future frames are buffered and return an empty vector until the missing lower sequence numbers arrive.