pub struct E2eStreamEncryptor { /* private fields */ }Expand description
Stateful streaming encryptor for direct ElGamal body frames.
Implementations
Sourceimpl E2eStreamEncryptor
impl E2eStreamEncryptor
Sourcepub fn new(
stream_id: Uuid,
sender_public_key: PublicKey<33>,
recipient_public_key: PublicKey<33>,
) -> Result<E2eStreamEncryptor, Error>
pub fn new( stream_id: Uuid, sender_public_key: PublicKey<33>, recipient_public_key: PublicKey<33>, ) -> Result<E2eStreamEncryptor, Error>
Create a direct ElGamal streaming encryptor for recipient_public_key.
Sourcepub fn encrypt_next(
&mut self,
plaintext: &[u8],
rng: &mut impl RngCore,
) -> Result<E2eStreamFrame, Error>
pub fn encrypt_next( &mut self, plaintext: &[u8], rng: &mut impl RngCore, ) -> Result<E2eStreamFrame, Error>
Encrypt one non-final plaintext frame.
Sourcepub fn encrypt_next_with_default_rng(
&mut self,
plaintext: &[u8],
) -> Result<E2eStreamFrame, Error>
pub fn encrypt_next_with_default_rng( &mut self, plaintext: &[u8], ) -> Result<E2eStreamFrame, Error>
Encrypt one non-final plaintext frame with the default thread-local RNG.
Sourcepub fn encrypt_final(
&mut self,
plaintext: &[u8],
rng: &mut impl RngCore,
) -> Result<E2eStreamFrame, Error>
pub fn encrypt_final( &mut self, plaintext: &[u8], rng: &mut impl RngCore, ) -> Result<E2eStreamFrame, Error>
Encrypt the final plaintext frame and close this stream.
Sourcepub fn encrypt_final_with_default_rng(
&mut self,
plaintext: &[u8],
) -> Result<E2eStreamFrame, Error>
pub fn encrypt_final_with_default_rng( &mut self, plaintext: &[u8], ) -> Result<E2eStreamFrame, Error>
Encrypt the final plaintext frame with the default thread-local RNG.