pub struct MessageVerification {
pub session: Session,
pub ttl_ms: u64,
pub ts_ms: u128,
pub sig: Vec<u8>,
}Expand description
Message Verification is based on session, and sig. it also included ttl time and created ts.
Fields
session: Sessionttl_ms: u64The time to live of the message in milliseconds.
ts_ms: u128The timestamp of the message in milliseconds.
sig: Vec<u8>Implementations
Sourceimpl MessageVerification
impl MessageVerification
Sourcepub fn new(
data: &[u8],
session_sk: &SessionSk,
) -> Result<MessageVerification, Error>
pub fn new( data: &[u8], session_sk: &SessionSk, ) -> Result<MessageVerification, Error>
Create a new MessageVerification. Should provide the data and the SessionSk.
Sourcepub fn is_expired(&self) -> bool
pub fn is_expired(&self) -> bool
Return whether the verification timestamp is outside its accepted lifetime.
Sourcepub fn is_live_at(&self, now_ms: u128) -> bool
pub fn is_live_at(&self, now_ms: u128) -> bool
Return whether the verification timestamp and TTL describe a currently live proof.
Pre: now_ms is the receiver’s current wall-clock time.
Post: true implies ttl_ms <= MAX_TTL_MS, the timestamp is not beyond the accepted future
skew, and now_ms has not passed ts_ms + ttl_ms.
Sourcepub fn verify_unexpired(&self, data: &[u8]) -> bool
pub fn verify_unexpired(&self, data: &[u8]) -> bool
Verify the signature only when the verification timestamp is still live.