pub struct SyncEntriesWithSuccessorReport {
pub purpose: StorageSyncPurpose,
pub destination: StorageSyncDestination,
pub receiver: Did,
pub acks: Vec<SyncedEntryAck>,
}Expand description
MessageType used to acknowledge durable storage of synced entries.
Fields
purpose: StorageSyncPurposeTransition kind of the original sync payload.
destination: StorageSyncDestinationOriginal storage-sync destination semantics.
receiver: DidPhysical receiver that produced this report.
acks: Vec<SyncedEntryAck>Placement keys and exact values durably persisted by the sync receiver.