pub struct Transaction {
pub destination: Did,
pub tx_id: Uuid,
pub data: Vec<u8>,
pub verification: MessageVerification,
}Expand description
All messages transmitted in RingsNetwork should be wrapped by Transaction.
It additionally offer destination, tx_id and verification.
To transmit Transaction in RingsNetwork, user should build
MessagePayload and use PayloadSender to send.
Fields
destination: DidThe destination of this message.
tx_id: UuidThe transaction ID. Remote peer should use same tx_id when response.
data: Vec<u8>data
verification: MessageVerificationThis field holds a signature from a node, which is used to prove that the transaction was created by that node.
Implementations
Sourceimpl Transaction
impl Transaction
Sourcepub fn new<T>(
destination: Did,
tx_id: Uuid,
data: T,
session_sk: &SessionSk,
) -> Result<Transaction, Error>where
T: Serialize,
pub fn new<T>(
destination: Did,
tx_id: Uuid,
data: T,
session_sk: &SessionSk,
) -> Result<Transaction, Error>where
T: Serialize,
Wrap data. Will serialize by bincode::serialize then sign MessageVerification by session_sk.
Sourcepub fn data<T>(&self) -> Result<T, Error>where
T: DeserializeOwned,
pub fn data<T>(&self) -> Result<T, Error>where
T: DeserializeOwned,
Deserializes the data field into a T instance.