Module types

Module types 

This module defines various message structures in the Rings network. Most of the messages follow the Ping/Pong pattern, where there is a one-to-one correspondence between them, such as xxxSend and xxxReport messages.

Structs

ConnectNodeReport
MessageType report to origin with own transport_uuid and handshake_info.
ConnectNodeSend
MessageType use to ask for connection, send to remote with transport_uuid and handshake_info.
CustomMessage
MessageType use to customize message, will be handle by custom_message method.
FindSuccessorReport
MessageType use to report origin node with report message.
FindSuccessorSend
MessageType use to find successor in a chord ring.
FoundEntry
MessageType used to report found DHT storage entries to the origin.
NotifyPredecessorReport
MessageType use to tell the real predecessor of current node.
NotifyPredecessorSend
MessageType use notify the successor about the predecessor inferred by current node.
QueryForTopoInfoReport
MessageType for handle crate::dht::PeerRingRemoteAction::QueryForSuccessorList
QueryForTopoInfoSend
MessageType for handle crate::dht::PeerRingRemoteAction::QueryForSuccessorList
SearchEntry
MessageType used to search a DHT storage entry.
SyncEntriesWithSuccessor
MessageType after FindSuccessorSend and syncing data.
SyncEntriesWithSuccessorReport
MessageType used to acknowledge durable storage of synced entries.

Enums

FindSuccessorReportHandler
MessageType enum handle when meet the last node.
FindSuccessorThen
MessageType enum Report contain FindSuccessorSend.
Message
A collection MessageType use for unified management.
QueryFor
The reason of query successor’s TopoInfo

Traits

Then
The Then trait is used to associate a type with a “then” scenario.