#[non_exhaustive]pub enum Message {
Show 20 variants
ConnectNodeSend(ConnectNodeSend),
ConnectNodeReport(ConnectNodeReport),
FindSuccessorSend(FindSuccessorSend),
FindSuccessorReport(FindSuccessorReport),
NotifyPredecessorSend(NotifyPredecessorSend),
NotifyPredecessorReport(NotifyPredecessorReport),
PeerLivenessProbe(PeerLivenessProbe),
PeerLivenessReport(PeerLivenessReport),
SearchEntry(SearchEntry),
FoundEntry(FoundEntry),
OperateEntry(PlacedEntryOperation),
SyncEntriesWithSuccessor(SyncEntriesWithSuccessor),
SyncEntriesWithSuccessorReport(SyncEntriesWithSuccessorReport),
CustomMessage(CustomMessage),
E2eHandshakeRequest(E2eHandshakeRequest),
E2eHandshakeResponse(E2eHandshakeResponse),
E2eStreamFrame(E2eStreamFrame),
QueryForTopoInfoSend(QueryForTopoInfoSend),
QueryForTopoInfoReport(QueryForTopoInfoReport),
Chunk(Chunk),
}Expand description
A collection MessageType use for unified management.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ConnectNodeSend(ConnectNodeSend)
Remote message of try connecting a node.
ConnectNodeReport(ConnectNodeReport)
Response of ConnectNodeSend.
FindSuccessorSend(FindSuccessorSend)
Remote message of find successor.
FindSuccessorReport(FindSuccessorReport)
Response of FindSuccessorSend.
NotifyPredecessorSend(NotifyPredecessorSend)
Remote message of notify a predecessor.
NotifyPredecessorReport(NotifyPredecessorReport)
Response of NotifyPredecessorSend.
PeerLivenessProbe(PeerLivenessProbe)
Overlay liveness probe.
PeerLivenessReport(PeerLivenessReport)
Overlay liveness probe response.
SearchEntry(SearchEntry)
Remote message for searching an entry.
FoundEntry(FoundEntry)
Response when entries are found.
OperateEntry(PlacedEntryOperation)
Remote message for entry operations.
SyncEntriesWithSuccessor(SyncEntriesWithSuccessor)
Remote message for entry syncing.
SyncEntriesWithSuccessorReport(SyncEntriesWithSuccessorReport)
Response after synced entries are durably persisted.
CustomMessage(CustomMessage)
Custom messages.
E2eHandshakeRequest(E2eHandshakeRequest)
Request to negotiate E2E ElGamal encryption with a signed public key.
E2eHandshakeResponse(E2eHandshakeResponse)
Response accepting E2E ElGamal encryption with a signed public key.
E2eStreamFrame(E2eStreamFrame)
Direct ElGamal-encrypted E2E stream frame.
QueryForTopoInfoSend(QueryForTopoInfoSend)
Remote message of query topological info of a node.
QueryForTopoInfoReport(QueryForTopoInfoReport)
Response of QueryForTopoInfoSend.
Chunk(Chunk)
A chunk that can be deserialized to a payload.
Implementations