pub struct MessageRelay {
pub path: Vec<Did>,
pub next_hop: Did,
pub destination: Did,
}Expand description
MessageRelay guide message passing on rings network by relay.
All messages should be sent with MessageRelay.
By calling relay method in correct place, MessageRelay help to do things:
- Record the whole transport path for inspection.
- Get the sender of a message.
Fields
path: Vec<Did>A push only stack. Record routes when handling messages.
next_hop: DidThe next node to handle the message. A message handler will pick transport by this field.
destination: DidThe destination of the message.
It may help the handler to find out next_hop in some situations.
Implementations
Sourceimpl MessageRelay
impl MessageRelay
Sourcepub fn new(path: Vec<Did>, next_hop: Did, destination: Did) -> MessageRelay
pub fn new(path: Vec<Did>, next_hop: Did, destination: Did) -> MessageRelay
Create a new MessageRelay.
Sourcepub fn forward(
&self,
current: Did,
next_hop: Did,
) -> Result<MessageRelay, Error>
pub fn forward( &self, current: Did, next_hop: Did, ) -> Result<MessageRelay, Error>
Validate relay, then create a new MessageRelay that have current did in the end of path.
The new relay will use next_hop as next_hop and self.destination as destination.
Sourcepub fn report(&self, current: Did) -> Result<MessageRelay, Error>
pub fn report(&self, current: Did) -> Result<MessageRelay, Error>
Validate relay, then create a new MessageRelay that used to report the message.
The new relay will use self.path[self.path.len() - 1] as next_hop and self.sender() as destination.
In the new relay, the path will be cleared and only have current did.
Sourcepub fn reset_destination(&self, destination: Did) -> MessageRelay
pub fn reset_destination(&self, destination: Did) -> MessageRelay
Sometime the sender may not know the destination of the message. They just use next_hop as destination. The next node can find a new next_hop, and may use this function to set that next_hop as destination again.
Sourcepub fn validate(&self, current: Did) -> Result<(), Error>
pub fn validate(&self, current: Did) -> Result<(), Error>
Check if path and destination is valid.
Sourcepub fn sender(&self) -> Did
👎Deprecated: please use origin_sender instead
pub fn sender(&self) -> Did
please use origin_sender instead
Get the origin sender of current message. Should be the first element of path.
Sourcepub fn try_origin_sender(&self) -> Result<Did, Error>
pub fn try_origin_sender(&self) -> Result<Did, Error>
Get the origin sender of current message as a checked relay-path boundary.
Sourcepub fn origin_sender(&self) -> Did
pub fn origin_sender(&self) -> Did
Get the origin sender of current message.
The origin should be the first element of path. Empty relay paths keep
the legacy fallback to destination; callers that must distinguish an
invalid relay boundary from a real origin should use
try_origin_sender.