pub struct PeerRing {
pub did: Did,
pub finger: Arc<Mutex<FingerTable>>,
pub successor_seq: SuccessorSeq,
pub predecessor: Arc<Mutex<Option<Did>>>,
pub storage: Box<dyn KvStorageInterface<Entry> + Send + Sync>,
pub cache: Box<dyn KvStorageInterface<Entry> + Send + Sync>,
}Expand description
PeerRing is used to help a node interact with other nodes. All nodes in rings network form a clockwise ring in the order of Did. This struct takes its name from that. PeerRing implemented Chord algorithm. PeerRing implemented ChordStorage protocol.
Fields
did: DidThe did of current node.
finger: Arc<Mutex<FingerTable>>FingerTable help node to find successor quickly.
successor_seq: SuccessorSeqThe next node on the ring. The SuccessorSeq may contain multiple node dids for fault tolerance. The min did should be same as the first element in finger table.
predecessor: Arc<Mutex<Option<Did>>>The did of previous node on the ring.
storage: Box<dyn KvStorageInterface<Entry> + Send + Sync>Local storage for ChordStorage.
cache: Box<dyn KvStorageInterface<Entry> + Send + Sync>Local cache for ChordStorage.
Implementations
Sourceimpl PeerRing
impl PeerRing
Sourcepub fn new_with_storage(
did: Did,
succ_max: u8,
storage: Box<dyn KvStorageInterface<Entry> + Send + Sync>,
) -> PeerRing
pub fn new_with_storage( did: Did, succ_max: u8, storage: Box<dyn KvStorageInterface<Entry> + Send + Sync>, ) -> PeerRing
Same as new with config, but with a given storage.
Sourcepub fn new_with_storage_and_finger_table_size(
did: Did,
succ_max: u8,
storage: Box<dyn KvStorageInterface<Entry> + Send + Sync>,
finger_table_size: usize,
) -> PeerRing
pub fn new_with_storage_and_finger_table_size( did: Did, succ_max: u8, storage: Box<dyn KvStorageInterface<Entry> + Send + Sync>, finger_table_size: usize, ) -> PeerRing
Same as new with config, but with a given storage and finger table size.
Did is 160-bit. Sizes above DEFAULT_FINGER_TABLE_SIZE are clamped
by FingerTable::new; zero is allowed to disable finger maintenance.
Sourcepub fn lock_successor(&self) -> Result<SuccessorSeq, Error>
👎Deprecated
pub fn lock_successor(&self) -> Result<SuccessorSeq, Error>
Return successor sequence. This function is deprecated, please use [chord.successors] instead.
Sourcepub fn successors(&self) -> SuccessorSeq
pub fn successors(&self) -> SuccessorSeq
Return successor sequence
Sourcepub fn lock_finger(&self) -> Result<MutexGuard<'_, FingerTable>, Error>
pub fn lock_finger(&self) -> Result<MutexGuard<'_, FingerTable>, Error>
Lock and return MutexGuard of finger table.
Sourcepub fn lock_predecessor(&self) -> Result<MutexGuard<'_, Option<Did>>, Error>
pub fn lock_predecessor(&self) -> Result<MutexGuard<'_, Option<Did>>, Error>
Lock and return MutexGuard of predecessor.