pub struct Session { /* private fields */ }Expand description
A serializable session proof used to verify messages signed by a delegated session key.
Implementations
Sourceimpl Session
impl Session
Sourcepub fn pack(&self) -> Vec<u8> ⓘ
pub fn pack(&self) -> Vec<u8> ⓘ
Pack the session into a string for verification or public key recovery.
Sourcepub fn session_did(&self) -> Did
pub fn session_did(&self) -> Did
Return the DID of the session public key.
Sourcepub fn is_expired(&self) -> bool
pub fn is_expired(&self) -> bool
Check whether the session has expired.
Sourcepub fn verify_self(&self) -> Result<(), Error>
pub fn verify_self(&self) -> Result<(), Error>
Verify that the account authorized this unexpired session.
Sourcepub fn verify(&self, msg: &[u8], sig: impl AsRef<[u8]>) -> Result<(), Error>
pub fn verify(&self, msg: &[u8], sig: impl AsRef<[u8]>) -> Result<(), Error>
Verify a message signed by this session key.
Sourcepub fn account_pubkey(&self) -> Result<PublicKey<33>, Error>
pub fn account_pubkey(&self) -> Result<PublicKey<33>, Error>
Get the legacy secp256k1-compatible account public key.
Use Session::account_verification_pubkey for typed account verification keys.
Sourcepub fn account_verification_pubkey(
&self,
) -> Result<VerificationPublicKey, Error>
pub fn account_verification_pubkey( &self, ) -> Result<VerificationPublicKey, Error>
Get the typed account verification public key from the session proof.
Sourcepub fn account_verifier(&self) -> AccountVerifier
pub fn account_verifier(&self) -> AccountVerifier
Get the typed account verifier.
Sourcepub fn account_did(&self) -> Did
pub fn account_did(&self) -> Did
Get the authorizing account DID.