SessionSk

Struct SessionSk 

pub struct SessionSk { /* private fields */ }
SessionSk holds the Session and its session private key. To prove that the message was sent by the Account of Session, we need to attach session and the signature signed by sk to the payload.

SessionSk provide a session method to clone the session. SessionSk also provide sign method to sign a message.

To verify the session, use verify_self() method of Session. To verify a message, use verify(msg, sig) method of Session.

Implementations

Source

impl SessionSk

pub fn new_with_seckey(key: &SecretKey) -> Result<SessionSk, Error>

Generate Session with private key. Only use it for unittest. To protect your private key, please use SessionSkBuilder to generate session.

pub fn session(&self) -> Session

Get session from SessionSk.

pub fn sign(&self, msg: &[u8]) -> Result<Vec<u8>, Error>

Sign message with session.

pub fn account_did(&self) -> Did

Get account did from session.

pub fn account_verifier(&self) -> AccountVerifier

Get typed account verifier from session.

pub fn dump(&self) -> Result<String, Error>

Dump session_sk to string, allowing user to save it in a config file. It can be restored using SessionSk::from_str.