pub struct SessionSkBuilder { /* private fields */ }Expand description
Builds a SessionSk from an external account authorization.
Implementations
Sourceimpl SessionSkBuilder
impl SessionSkBuilder
Sourcepub fn new(account_entity: String, account_type: String) -> SessionSkBuilder
pub fn new(account_entity: String, account_type: String) -> SessionSkBuilder
Create a new SessionSkBuilder.
account_type is the lowercase account algorithm name and account_entity is the encoded
entity accepted by that account algorithm.
Sourcepub fn validate_account(&self) -> bool
pub fn validate_account(&self) -> bool
Return whether the configured account type and entity form a valid account.
Sourcepub fn unsigned_proof(&self) -> String
pub fn unsigned_proof(&self) -> String
Construct the proof string that the external account must sign.
Sourcepub fn set_session_sig(self, sig: Vec<u8>) -> SessionSkBuilder
pub fn set_session_sig(self, sig: Vec<u8>) -> SessionSkBuilder
Set the account signature authorizing this session.
Sourcepub fn set_ttl(self, ttl_ms: u64) -> SessionSkBuilder
pub fn set_ttl(self, ttl_ms: u64) -> SessionSkBuilder
Set the session lifetime.