pub struct Swarm { /* private fields */ }Expand description
The transport and dht management.
Implementations
Sourceimpl Swarm
impl Swarm
Sourcepub fn account_pubkey(&self) -> Result<PublicKey<33>, Error>
pub fn account_pubkey(&self) -> Result<PublicKey<33>, Error>
Get the local account public key used for E2E public-key negotiation.
Sourcepub fn set_callback(
&self,
callback: Arc<dyn SwarmCallback + Send + Sync>,
) -> Result<(), Error>
pub fn set_callback( &self, callback: Arc<dyn SwarmCallback + Send + Sync>, ) -> Result<(), Error>
Set callback for swarm.
Sourcepub fn stabilizer(&self) -> Stabilizer
pub fn stabilizer(&self) -> Stabilizer
Create Stabilizer for swarm.
Sourcepub async fn disconnect(&self, peer: Did) -> Result<(), Error>
pub async fn disconnect(&self, peer: Did) -> Result<(), Error>
Disconnect a connection. There are three steps:
- remove from DHT;
- remove from Transport;
- close the connection;
Sourcepub async fn connect(&self, peer: Did) -> Result<(), Error>
pub async fn connect(&self, peer: Did) -> Result<(), Error>
Connect a given Did. If the did is already connected, return directly, else try prepare offer and establish connection by dht. This function may returns a pending connection or connected connection.
Sourcepub async fn send_message(
&self,
msg: Message,
destination: Did,
) -> Result<Uuid, Error>
pub async fn send_message( &self, msg: Message, destination: Did, ) -> Result<Uuid, Error>
Send Message to peer.
Sourcepub fn peers(&self) -> Vec<ConnectionInspect>
pub fn peers(&self) -> Vec<ConnectionInspect>
List peers and their connection status.
Sourcepub async fn inspect(&self) -> SwarmInspect
pub async fn inspect(&self) -> SwarmInspect
Check the status of swarm
Sourceimpl Swarm
impl Swarm
Sourcepub async fn create_offer(&self, peer: Did) -> Result<MessagePayload, Error>
pub async fn create_offer(&self, peer: Did) -> Result<MessagePayload, Error>
Create new connection and its answer. This function will wrap the offer inside a payload with verification.
Sourcepub async fn answer_offer(
&self,
offer_payload: MessagePayload,
) -> Result<MessagePayload, Error>
pub async fn answer_offer( &self, offer_payload: MessagePayload, ) -> Result<MessagePayload, Error>
Answer the offer of remote connection. This function will verify the answer payload and will wrap the answer inside a payload with verification.
Sourcepub async fn accept_answer(
&self,
answer_payload: MessagePayload,
) -> Result<(), Error>
pub async fn accept_answer( &self, answer_payload: MessagePayload, ) -> Result<(), Error>
Accept the answer of remote connection. This function will verify the answer payload and will return its did with the connection.