Module processor

Module processor 

Processor of rings-node rpc server.

Structs

Processor
Processor for rings-node rpc server
ProcessorBuilder
ProcessorBuilder is used to initialize a Processor instance.
ProcessorConfig
ProcessorConfig is usually serialized as json or yaml. There is a from_config method in ProcessorBuilder used to initialize the Builder with a serialized ProcessorConfig.
ProcessorConfigSerialized
ProcessorConfigSerialized is a serialized version of ProcessorConfig. Instead of storing the SessionSk instance, it stores the dumped string representation of the session secret key.