pub struct RegistrationContext<'a> { /* private fields */ }Expand description
Capability passed to registration tasks.
The context exposes only the node facts and DHT publication operation that a registry needs. The task does not own the processor.
Implementations
Sourceimpl<'a> RegistrationContext<'a>
impl<'a> RegistrationContext<'a>
Sourcepub fn should_stop(&self) -> bool
pub fn should_stop(&self) -> bool
Return whether the owning registration daemon has requested shutdown.
Sourcepub fn network_id(&self) -> u32
pub fn network_id(&self) -> u32
Return the local network id.
Sourcepub fn storage_redundancy(&self) -> u16
pub fn storage_redundancy(&self) -> u16
Return storage redundancy for the local DHT protocol mode.
Sourcepub fn dht_virtual_nodes(&self) -> u16
pub fn dht_virtual_nodes(&self) -> u16
Return storage virtual-node positions for the local DHT protocol mode.
Sourcepub fn account_verification_pubkey(&self) -> Result<VerificationPublicKey>
pub fn account_verification_pubkey(&self) -> Result<VerificationPublicKey>
Return the account verification public key.
Sourcepub fn session_sk(&self) -> &SessionSk
pub fn session_sk(&self) -> &SessionSk
Return the local session signing key.