Module util

Module util 

Utilities for configuration and build.

Modules

loader
A module to help user load config from local file or remote url.

Functions

build_version
build_version of program
ensure_parent_dir
Create parent directory of a path if not exists.
expand_home
Expand path with “~” to absolute path.