A module to help user load config from local file or remote url.
Traits
- Resource
Loader - Load config from local file or remote url. To use this trait, derive DeserializeOwned then implement this trait.
A module to help user load config from local file or remote url.