#[non_exhaustive]#[repr(u32)]pub enum Error {
Show 60 variants
RemoteRpcError(String),
UnknownRpcError = 101,
InternalRpcError(Error),
UuidError(Error),
ConnectionNotFound = 203,
NewConnectionError(Error),
CloseConnectionError(Error),
InvalidConnectionId = 206,
CreateOffer(Error),
AnswerOffer(Error),
AcceptAnswer(Error),
DecodeError = 300,
EncodeError = 301,
WasmCompileError(String),
WasmBackendMessageRwLockError = 401,
WasmInstantiationError = 402,
WasmExportError = 403,
WasmRuntimeError(String),
WasmGlobalMemoryLockError = 405,
WasmFailedToLoadFile = 406,
InvalidDid(String),
InvalidMethod = 501,
InternalError(Error),
NoPermission = 504,
ConnectError(Error),
SendMessage(Error),
EntryError(Error),
ServiceRegisterError(Error),
JsError(String),
InvalidMessage = 800,
HttpRequestError(String),
InvalidData = 802,
InvalidService = 803,
InvalidAddress = 804,
InvalidAuthData = 805,
InvalidHeaders = 806,
Storage(Error),
Swarm(Error),
InvalidLoggingLevel(String),
CreateFileError(String),
OpenFileError(String),
Lock = 902,
HomeDirError = 903,
ParentDirError = 904,
SerdeJsonError(Error),
SerdeYamlError(Error),
VerifyError(String),
CoreError(Error),
ExternalError(String),
FFINulError(NulError),
FFICStrError(Utf8Error),
FFINulPtrError = 1_205,
FFIFromUtf8Error(FromUtf8Error),
RingsSNARKError(Error),
SNARKCurveNotMatch(),
SNARKHandleMessage(String),
SNARKWrongField(String),
FailedToLoadFF(),
BackendError(String),
ExtensionError(String),
}Expand description
Errors enum mapping global custom errors. The error type can be expressed in decimal, where the high decs represent the error category and the low decs represent the error type.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
RemoteRpcError(String)
UnknownRpcError = 101
InternalRpcError(Error)
UuidError(Error)
ConnectionNotFound = 203
NewConnectionError(Error)
CloseConnectionError(Error)
InvalidConnectionId = 206
CreateOffer(Error)
AnswerOffer(Error)
AcceptAnswer(Error)
DecodeError = 300
EncodeError = 301
WasmCompileError(String)
WasmBackendMessageRwLockError = 401
WasmInstantiationError = 402
WasmExportError = 403
WasmRuntimeError(String)
WasmGlobalMemoryLockError = 405
WasmFailedToLoadFile = 406
InvalidDid(String)
InvalidMethod = 501
InternalError(Error)
NoPermission = 504
ConnectError(Error)
SendMessage(Error)
EntryError(Error)
ServiceRegisterError(Error)
JsError(String)
InvalidMessage = 800
HttpRequestError(String)
InvalidData = 802
InvalidService = 803
InvalidAddress = 804
InvalidAuthData = 805
InvalidHeaders = 806
Storage(Error)
Swarm(Error)
InvalidLoggingLevel(String)
CreateFileError(String)
OpenFileError(String)
Lock = 902
HomeDirError = 903
ParentDirError = 904
SerdeJsonError(Error)
SerdeYamlError(Error)
VerifyError(String)
CoreError(Error)
ExternalError(String)
FFINulError(NulError)
FFICStrError(Utf8Error)
FFINulPtrError = 1_205
FFIFromUtf8Error(FromUtf8Error)
RingsSNARKError(Error)
SNARKCurveNotMatch()
SNARKHandleMessage(String)
SNARKWrongField(String)
FailedToLoadFF()
BackendError(String)
ExtensionError(String)
Implementations