This module implemented the Measure trait for swarm.
Structs
- Periodic
Measure PeriodicMeasureis used to assess the reliability of peers by counting their behaviour. It currently count the number of sent and received messages in a given period (1 hour). The method Measure::incr should be called in the proper places.
Type Aliases
- Measure
Storage MeasureStorageis the type accepted byPeriodicMeasure::new. It’s used to store counts in a storage media provided by user.