Native JSON-RPC endpoint server.
rings-node service run with Swarm and chord stabilization.
Structs
- Gateway
Status State - Gateway status endpoint state.
- Json
Response - JSON response struct
- Json
RpcState - JSON-RPC state
- Status
State - Status state
- WsState
- websocket state
Functions
- run_
external_ api - Run a web server to handle jsonrpc request from external
- run_
internal_ api - Run a web server to handle jsonrpc request locally
- run_
internal_ api_ with_ gateway - Run the local JSON-RPC server with an optional foreground-gateway status endpoint.