Module endpoint

Module endpoint 

rings-node service run with Swarm and chord stabilization.

Structs

JsonResponse
JSON response struct
JsonRpcState
JSON-RPC state
StatusState
Status state
WsState
websocket state

Functions

run_external_api
Run a web server to handle jsonrpc request from external
run_internal_api
Run a web server to handle jsonrpc request locally