pub trait OnionCircuitHandler {
// Required methods
fn handle_exit<'life0, 'life1, 'async_trait>(
&'life0 self,
scope: &'life1 Scope,
frame: OnionCircuitExitFrame,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn handle_client<'life0, 'life1, 'async_trait>(
&'life0 self,
scope: &'life1 Scope,
from: Did,
circuit_id: OnionCircuitId,
payload: OnionAuthenticatedPayload,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
}Expand description
Runtime-specific circuit handling.
Required Methods
Sourcefn handle_exit<'life0, 'life1, 'async_trait>(
&'life0 self,
scope: &'life1 Scope,
frame: OnionCircuitExitFrame,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn handle_exit<'life0, 'life1, 'async_trait>(
&'life0 self,
scope: &'life1 Scope,
frame: OnionCircuitExitFrame,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Handle a frame that reached this node as the exit.
Sourcefn handle_client<'life0, 'life1, 'async_trait>(
&'life0 self,
scope: &'life1 Scope,
from: Did,
circuit_id: OnionCircuitId,
payload: OnionAuthenticatedPayload,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn handle_client<'life0, 'life1, 'async_trait>(
&'life0 self,
scope: &'life1 Scope,
from: Did,
circuit_id: OnionCircuitId,
payload: OnionAuthenticatedPayload,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Handle a frame that reached this node as the client.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".