Module prelude

Module prelude 

A prelude is provided which imports all the important data types and traits of ring-network.

Re-exports

pub use crate::onion::proxy::OnionProxyConfig;
pub use crate::onion::proxy::OnionProxyProtocol;
pub use crate::onion::proxy::OnionProxyRoute;
pub use crate::onion::proxy::OnionProxyTarget;
pub use crate::onion::proxy::ONION_PROXY_HTTPS_SERVICE;
pub use crate::onion::proxy::ONION_PROXY_TCP_SERVICE;
pub use crate::onion::OnionExitDescriptor;
pub use crate::onion::OnionExitPolicy;
pub use crate::onion::OnionExitRegistration;
pub use crate::onion::OnionExitService;
pub use crate::onion::OnionExitTransport;
pub use crate::onion::OnionRoute;
pub use crate::onion::OnionRouteRequest;
pub use crate::onion::ONION_EXITS_TOPIC;
pub use crate::onion::ONION_RELAY_CAPABILITY;
pub use crate::online::OnlineNodeDescriptor;
pub use crate::online::OnlineNodeType;
pub use crate::online::ONLINE_NODES_TOPIC;
pub use crate::online::ONLINE_NODE_CAPABILITY_STORAGE;
pub use crate::registration::DhtRegistrationPublisher;
pub use crate::registration::RegistrationContext;
pub use crate::registration::RegistrationTask;
pub use base58;
pub use rings_core;
pub use uuid;

Modules

chunk
Message framing / chunking. A message larger than the connection’s negotiated max_message_size is split into MTU-sized Chunks on the sender and reassembled on the receiver.
entry
Storage entry model used by Chord-backed DHT storage.
message
Message and MessageHandler

Structs

CustomMessage
MessageType use to customize message, will be handle by custom_message method.
MessageHandler
Shared message-handler handle.
MessagePayload
MessagePayload is used to transmit data between nodes. The data should be packed by Transaction.
MessageRelay
MessageRelay guide message passing on rings network by relay.
PeerMeasurement
Projected local measurement for one Rings peer.
PeerRing
Chord routing and replicated-storage state for one network peer.
SecretKey
Secp256k1 secret key bytes.
Session
A serializable session proof used to verify messages signed by a delegated session key.
SessionSk
A verified Session and its delegated private signing key.
SessionSkBuilder
Builds a SessionSk from an external account authorization.
StopSource
Authority that can request cooperative shutdown for one lifecycle scope.
StopToken
Read-only cooperative shutdown capability for long-running loops.
Swarm
The transport and dht management.
SwarmBuilder
Creates a SwarmBuilder to configure a Swarm.

Enums

Message
A collection MessageType use for unified management.
ReportReturnPolicy
Policy used when sending a report for a request payload.

Traits

ChordStorageInterface
ChordStorageInterface should imply necessary method for DHT storage
ChordStorageInterfaceCacheChecker
ChordStorageInterfaceCacheChecker defines the interface for checking the local cache of the DHT.
PayloadSender
Trait of PayloadSender

Attribute Macros

async_trait
wasm_export
If the feature is not “wasm”, the macro does nothing; otherwise, it calls wasm_bindgen. wasm_export does not work for Js Class. To export a class to js, you should use wasm_bindgen or __wasm_bindgen_class_marker. ref: https://docs.rs/wasm-bindgen-macro/0.2.86/src/wasm_bindgen_macro/lib.rs.html#51