Module rings_node::prelude::chunk

source ·
A Framing and Message chucking implementation defined in RFC4917https://www.rfc-editor.org/rfc/rfc4975#page-9 This chunking mechanism allows a sender to interrupt a chunk part of the way through sending it. The ability to interrupt messages allows multiple sessions to share a TCP connection, and for large messages to be sent efficiently while not blocking other messages that share the same connection, or even the same MSRP session.

Structs

A data structure to presenting Chunks
List of Chunk, simply wrapped Vec<Chunk>
Meta data of a chunk

Traits

A helper for manage chunks and chunk pool