FindSuccessorReport

Struct FindSuccessorReport 

pub struct FindSuccessorReport {
    pub did: Did,
    pub handler: FindSuccessorReportHandler,
}
MessageType use to report origin node with report message.

Fields

did: Did

did of target

handler: FindSuccessorReportHandler

handler event after processed then of FindSuccessorSend. Usually it will contains then from FindSuccessorSend, And when sender received report, it should call related handler for the event