pub struct FindSuccessorReport {
pub did: Did,
pub handler: FindSuccessorReportHandler,
}Expand description
MessageType use to report origin node with report message.
Fields
did: Diddid of target
handler: FindSuccessorReportHandlerhandler event after processed then of FindSuccessorSend.
Usually it will contains then from FindSuccessorSend,
And when sender received report, it should call related handler for the event