pub struct FindSuccessorSend {
pub did: Did,
pub strict: bool,
pub then: FindSuccessorThen,
}Expand description
MessageType use to find successor in a chord ring.
Fields
did: Diddid of target
strict: boolif strict is true, it will try to find the exactly did, else it will try to find the closest did.
then: FindSuccessorThenevents should be triggered after found successor