This module defines various message structures in the Rings network. Most of the messages follow the Ping/Pong pattern, where there is a one-to-one correspondence between them, such as xxxSend and xxxReport messages.
Structs
- Connect
Node Report - MessageType report to origin with own transport_uuid and handshake_info.
- Connect
Node Send - MessageType use to ask for connection, send to remote with transport_uuid and handshake_info.
- Custom
Message - MessageType use to customize message, will be handle by
custom_messagemethod. - Find
Successor Report - MessageType use to report origin node with report message.
- Find
Successor Send - MessageType use to find successor in a chord ring.
- Found
Entry - MessageType used to report found DHT storage entries to the origin.
- Notify
Predecessor Report - MessageType use to tell the real predecessor of current node.
- Notify
Predecessor Send - MessageType use notify the successor about the predecessor inferred by current node.
- Query
ForTopo Info Report - MessageType for handle crate::dht::PeerRingRemoteAction::QueryForSuccessorList
- Query
ForTopo Info Send - MessageType for handle crate::dht::PeerRingRemoteAction::QueryForSuccessorList
- Search
Entry - MessageType used to search a DHT storage entry.
- Sync
Entries With Successor - MessageType after
FindSuccessorSendand syncing data. - Sync
Entries With Successor Report - MessageType used to acknowledge durable storage of synced entries.
Enums
- Find
Successor Report Handler - MessageType enum handle when meet the last node.
- Find
Successor Then - MessageType enum Report contain FindSuccessorSend.
- Message
- A collection MessageType use for unified management.
- Query
For - The reason of query successor’s TopoInfo
Traits
- Then
- The
Thentrait is used to associate a type with a “then” scenario.