pub struct SecretKey(/* private fields */);Expand description
Secp256k1 secret key bytes.
The bytes are validated at construction time and stay in the canonical external format used by existing configs and DIDs.
Implementations
Sourceimpl SecretKey
impl SecretKey
Sourcepub fn sign(&self, message: &str) -> [u8; 65]
pub fn sign(&self, message: &str) -> [u8; 65]
Sign a UTF-8 message after hashing it with Keccak-256.
Sourcepub fn sign_raw(&self, message: &[u8]) -> [u8; 65]
pub fn sign_raw(&self, message: &[u8]) -> [u8; 65]
Sign raw message bytes after hashing them with Keccak-256.