pub trait ChordStorageInterfaceCacheChecker {
// Required method
fn storage_check_cache<'life0, 'async_trait>(
&'life0 self,
entry_key: Did,
) -> Pin<Box<dyn Future<Output = Option<Entry>> + Send + 'async_trait>>
where 'life0: 'async_trait,
Self: 'async_trait;
}Expand description
ChordStorageInterfaceCacheChecker defines the interface for checking the local cache of the DHT.
Required Methods
Sourcefn storage_check_cache<'life0, 'async_trait>(
&'life0 self,
entry_key: Did,
) -> Pin<Box<dyn Future<Output = Option<Entry>> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn storage_check_cache<'life0, 'async_trait>(
&'life0 self,
entry_key: Did,
) -> Pin<Box<dyn Future<Output = Option<Entry>> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Check the local cache of the DHT for a specific entry key.
Returns an optional Entry representing the cached data, or None if it is not found.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".