Processor of rings-node rpc server.
Structs
- Processor
- Processor for rings-node rpc server
- Processor
Builder - ProcessorBuilder is used to initialize a Processor instance.
- Processor
Config - ProcessorConfig is usually serialized as json or yaml.
There is a
from_configmethod in ProcessorBuilder used to initialize the Builder with a serialized ProcessorConfig. - Processor
Config Serialized ProcessorConfigSerializedis a serialized version ofProcessorConfig. Instead of storing theSessionSkinstance, it stores the dumped string representation of the session secret key.