Utilities for configuration and build.
Modules
- loader
- A module to help user load config from local file or remote url.
Functions
- build_
version - build_version of program
- ensure_
parent_ dir - Create parent directory of a path if not exists.
- expand_
home - Expand path with “~” to absolute path.