Module util

Module util 

Utilities for configuration and build.

Modules

loader
A module to help user load config from local file or remote url.

Functions

build_version
build_version of program
deserialize_forward
Deserialize a value through Serde without an intermediate wrapper.
deserialize_gzip
Deserialize gzipped JSON bytes into a value.
ensure_parent_dir
Create parent directory of a path if not exists.
expand_home
Expand path with “~” to absolute path.
serialize_forward
Serialize a value through Serde without an intermediate wrapper.
serialize_gzip
Serialize a value as gzipped JSON bytes.