Utilities for configuration and build.
Modules
- loader
- A module to help user load config from local file or remote url.
Functions
- build_
version - build_version of program
- deserialize_
forward - Deserialize a value through Serde without an intermediate wrapper.
- deserialize_
gzip - Deserialize gzipped JSON bytes into a value.
- ensure_
parent_ dir - Create parent directory of a path if not exists.
- expand_
home - Expand path with “~” to absolute path.
- serialize_
forward - Serialize a value through Serde without an intermediate wrapper.
- serialize_
gzip - Serialize a value as gzipped JSON bytes.